@@ -3,8 +3,8 @@ change.coord <- function(basis, points) {
     dim.basis <- dim(basis)
     num.coord <- dim.points[2]
     
-    matrix.change.coord <- matrix(rep(0, num.coord * num.coord * dim.points[1]), 
-        ncol = num.coord * num.coord)
+    matrix.change.coord <- matrix(rep(0, num.coord * num.coord * dim.points[1]), ncol = num.coord * 
+        num.coord)
     
     for (i in 1:num.coord) {
         x.i <- points[, i]
