@@ -13,13 +13,18 @@
 #' \dontrun{
 #' data(ex1_db2so)
 #' data.sym <- classic.to.sym(ex1_db2so, concept=c("state", "sex"),
-#'                            variables=c("county", "group", "age","age","age","age"),
-#'                            variables.types=c("$I", "$C", "$C", "$S", "$M","$H"))
+#'                            col.names = c(county, group, age,age,age,age),
+#'                            variables.types=c(county = type.interval(),
+#'                            group = type.continuous(),
+#'                            age = type.continuous(),
+#'                             age = type.continuous(),
+#'                             age = type.modal(),
+#'                             age = type.histogram()))
 #' sym.continuos.plot(data.sym[1,2])
 #' }
 sym.continuos.plot <- function(info,col=c("blue"),border=FALSE,show.type = TRUE){
-  #if(info$sym.var.types != "$C")
-  #  stop("The data type is wrong, only $C are accepted")
+  if(info$sym.var.types != "$C")
+    stop("The data type is wrong, only $C are accepted")
   continuos <- as.numeric(info$data)
   plot(continuos+c(-0.5,0.5), c(0,4.1), type= "n", xlab = "", ylab = "",main = paste(info$sym.var.names,ifelse(show.type," (Continuos)","")),yaxt='n')
   abline(v=continuos, col=col, lty=2, lwd=2)
